@@ -53,8 +53,9 @@ class GnuTLSGenerator(ConfigGenerator):
         'FFDHE-3072': 'GROUP-FFDHE3072',
         'FFDHE-4096': 'GROUP-FFDHE4096',
         'FFDHE-8192': 'GROUP-FFDHE8192',
-        'X25519-MLKEM768': 'GROUP-X25519-MLKEM768',
+        'MLKEM768-X25519': 'GROUP-X25519-MLKEM768',
         'P256-MLKEM768': 'GROUP-SECP256R1-MLKEM768',
+        'P384-MLKEM1024': 'GROUP-SECP384R1-MLKEM1024',
     }
 
     group_curve_map = {
@@ -64,6 +65,9 @@ class GnuTLSGenerator(ConfigGenerator):
         'SECP256R1': 'SECP256R1',
         'SECP384R1': 'SECP384R1',
         'SECP521R1': 'SECP521R1',
+        'MLKEM768-X25519': 'X25519',
+        'P256-MLKEM768': 'SECP256R1',
+        'P384-MLKEM1024': 'SECP384R1',
     }
 
     sign_curve_map = {
@@ -112,6 +116,10 @@ class GnuTLSGenerator(ConfigGenerator):
 
         'EDDSA-ED448': ['EdDSA-Ed448'],
         'EDDSA-ED25519': ['EdDSA-Ed25519'],
+
+        'MLDSA44': ['ML-DSA-44'],
+        'MLDSA65': ['ML-DSA-65'],
+        'MLDSA87': ['ML-DSA-87'],
     }
 
     cipher_map = {
@@ -211,12 +219,19 @@ class GnuTLSGenerator(ConfigGenerator):
             s += 'secure-sig-for-cert = ecdsa-sha1\n'
 
         # with allowlisting, curves now need to be enabled separately
+        enabled_curves = []
         for i in p['group']:
             if i in cls.group_curve_map:
-                s += f'enabled-curve = {cls.group_curve_map[i]}\n'
+                c = cls.group_curve_map[i]
+                if c not in enabled_curves:
+                    enabled_curves.append(c)
         for i in p['sign']:
             if i in cls.sign_curve_map:
-                s += f'enabled-curve = {cls.sign_curve_map[i]}\n'
+                c = cls.sign_curve_map[i]
+                if c not in enabled_curves:
+                    enabled_curves.append(c)
+        for c in enabled_curves:
+            s += f'enabled-curve = {c}\n'
 
         if p['cipher']:
             for i in p['cipher']:
